<?php

//  Not allowed to access directly
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("PackagingTab")) {
    class PackagingTab extends EnPalletWooAddonPluginDetail
    {
        public $box_sizing_text_fields_arr;
        public $subscriptionStatus;
        public $settings;
        public $section;
        public $plugin_id;
        public $plugins_dependencies;

        function __construct()
        {
            $this->box_sizing_text_fields_arr = $this->en_woo_addons_box_sizing_text_fields_arr();

            add_filter('en_woo_pallet_addons_sections', array($this, 'en_woo_pallet_addons_sections'), 10, 2);
            add_filter('en_woo_pallet_addons_settings', array($this, 'en_woo_pallet_addons_settings'), 10, 3);

            add_action('woocommerce_settings_tabs_array', array($this, 'en_woo_addons_popup_notifi_disabl_to_plan_pallet'), 10);

            add_action('woocommerce_settings_wc_settings_quote_section_end_pallet_sizing_after', array($this, 'enPalletTable'));
            add_action('woocommerce_settings_wc_settings_quote_section_end_pallet_sizing_after', array($this, 'en_pallet_re_arrange_fields'));

        }

        /**
         * Plugins dependencies array merge
         * @return array
         */
        public function plugins_dependencies()
        {
            $plugins_dependies = array();
            $plugins_dependies_function_arr = array(
                'freightview_quotes_dependencies',
                'ups_freight_quotes_dependencies',
                'yrc_quotes_dependencies',
            );

            foreach ($plugins_dependies_function_arr as $value) {
                $plugins_dependies = array_merge($plugins_dependies, $this->$value());
            }
            $plugins_dependies = apply_filters('en_woo_addons_plugin_dependencies_apply_filters', $plugins_dependies);

            return $plugins_dependies;
        }

        /**
         * Update web api settings array
         * @param array $settings
         * @param string $section
         * @param string $plugin_id
         * @return array
         */
        public function en_woo_pallet_addons_settings($settings, $section, $plugin_id)
        {
            $this->settings = $settings;
            $this->section = $section;
            $this->plugin_id = $plugin_id;

            $this->plugins_dependencies = $this->plugins_dependencies();

            if (isset($this->plugins_dependencies[$this->plugin_id])) {
                $plugin_detail = $this->plugins_dependencies[$this->plugin_id];
                $addons = $plugin_detail['addons'];
                if ($addons['pallet_packaging_addon']['active'] === true && $this->section == $addons['pallet_packaging_addon']['section']) {
                    $this->EnWooPalletAddonsCurlReqIncludes = new EnWooPalletAddonsCurlReqIncludes();
                    $this->settings = $this->en_woo_addons_box_sizing_fields_arr($this->plugin_id);
                }
            }

            return $this->settings;
        }

        /**
         * Smart street api response curl from server
         * @return array type
         */
        public function customer_subscription_status()
        {

            $this->en_trial_activation_bin();
            $status = $this->EnWooPalletAddonsCurlReqIncludes->smart_street_api_curl_request("s",
                $this->plugin_name);
            $this->en_check_plugin_status($status);
            $status = json_decode($status, true);
            return $status;
        }

        /**
         * Trial activation of 3dbin.
         */
        public function en_trial_activation_bin()
        {
            $trial_status = '';
            /* Trial activation code */
            $trial_status_3dbin = get_option('en_trial_activation_pallet');
            if (!$trial_status_3dbin) {
                $trial_status = $this->EnWooPalletAddonsCurlReqIncludes->smart_street_api_curl_request("c",
                    $this->plugin_name, 'TR');
                $response_status = json_decode($trial_status);
                /* Trial Package activated succesfully */
                if (isset($response_status->severity) && $response_status->severity == "SUCCESS") {
                    update_option('en_trial_activation_pallet', 1);
                }
                /* Error response */
                if (isset($response_status->severity) && $response_status->severity == "ERROR") {
                    /* Do anthing in case of error */
                }
            }
        }

        /**
         * Check plugin status.
         */
        public function en_check_plugin_status($current_status)
        {
            $current_status = json_decode($current_status);
            if (
                isset($current_status->status->subscribedPackage->packageSCAC) &&
                $current_status->status->subscribedPackage->packageSCAC == 'TR'
            ) {
                $plugin_status = $this->EnWooPalletAddonsCurlReqIncludes->smart_street_api_curl_request("pluginType",
                    $this->plugin_name, '');
                $decoded_plugin_status = json_decode($plugin_status);
                if ($decoded_plugin_status->severity == "SUCCESS") {
                    if ($decoded_plugin_status->pluginType == "trial") {
                        /* Plugin not activated notification */
                        echo '<div id="message" class="notice-dismiss-bin notice-dismiss-bin-php notice-warning notice is-dismissible"><p>The Freight Quotes plugin must have an active paid license to continue to use this feature.</p><button type="button" class="notice-dismiss notice-dismiss-bin"><span class="screen-reader-text notice-dismiss-bin">Dismiss this notice.</span></button></div>';
                    }
                }
            }
        }

        public function packages_list($packages_list)
        {
            $packages_list_arr = array();
            if (isset($packages_list) && (!empty($packages_list))) {

                $packages_list_arr['options']['disable'] = 'Disable (default)';
                foreach ($packages_list as $key => $value) {
                    $value['pPeriod'] = (isset($value['pPeriod']) && ($value['pPeriod'] == "Month")) ? "mo" : $value['pPeriod'];
                    $value['pHits'] = is_numeric($value['pHits']) ? number_format($value['pHits']) : $value['pHits'];
                    $value['pCost'] = is_numeric($value['pCost']) ? number_format($value['pCost'], 2, '.', '') : $value['pCost'];
                    $trial = (isset($value['pSCAC']) && $value['pSCAC'] == "TR") ? "(Trial)" : "";
                    $packages_list_arr['options'][$value['pSCAC']] = $value['pHits'] . "/" . $value['pPeriod'] . " ($" . number_format($value['pCost']) . ".00)" . " " . $trial;

                }
            }
            return $packages_list_arr;
        }

        /**
         * Ui display for next plan
         * @return string type
         */
        public function next_subcribed_package()
        {

            $this->next_subcribed_package = (isset($this->nextSubcribedPackage['nextToBeChargedStatus']) && $this->nextSubcribedPackage['nextToBeChargedStatus'] == 1) ? $this->nextSubcribedPackage['nextSubscriptionSCAC'] : "disable";
            return $this->next_subcribed_package;
        }

        public function subscribed_package()
        {
            $subscribed_package = $this->subscribedPackage;
            $subscribed_package['packageDuration'] = (isset($subscribed_package['packageDuration']) && ($subscribed_package['packageDuration'] == "Month")) ? "mo" : $subscribed_package['packageDuration'];
            $subscribed_package['packageHits'] = is_numeric($subscribed_package['packageHits']) ? number_format($subscribed_package['packageHits']) : $subscribed_package['packageHits'];
            $subscribed_package['packageCost'] = is_numeric($subscribed_package['packageCost']) ? number_format($subscribed_package['packageCost'], 2, '.', '') : $subscribed_package['packageCost'];
            return $subscribed_package['packageHits'] . "/" . $subscribed_package['packageDuration'] . " ($" . number_format($subscribed_package['packageCost']) . ".00)";
        }

        /**
         * Response from smart street api and set in public attributes
         */
        function set_curl_res_attributes()
        {

            $this->subscriptionInfo = (isset($this->status['status']['subscriptionInfo'])) ? $this->status['status']['subscriptionInfo'] : "";
            $this->lastUsageTime = (isset($this->status['status']['lastUsageTime'])) ? $this->status['status']['lastUsageTime'] : "";
            $this->subscribedPackage = (isset($this->status['status']['subscribedPackage'])) ? $this->status['status']['subscribedPackage'] : "";
            $this->subscriptionStatus = (isset($this->status['status']['subscriptionInfo']['subscriptionStatus'])) ? ($this->status['status']['subscriptionInfo']['subscriptionStatus'] == 1) ? "yes" : "no" : "";
            $this->subscribedPackageHitsStatus = (isset($this->status['status']['subscribedPackageHitsStatus'])) ? $this->status['status']['subscribedPackageHitsStatus'] : "";
            $this->nextSubcribedPackage = (isset($this->status['status']['nextSubcribedPackage'])) ? $this->status['status']['nextSubcribedPackage'] : "";
            $this->statusRequestTime = (isset($this->status['statusRequestTime'])) ? $this->status['statusRequestTime'] : "";
//                $this->subscriptionStatus =  "no";
        }


        /**
         * UI display Current Subscription & Current Usage
         * @param array type $status
         * @return array type
         */
        public function subscription($status = array())
        {

            if (isset($status) && (!empty($status)) && (is_array($status))) {
                $this->status = $status;
            } else { /* onload */
                $this->status = $this->customer_subscription_status();
                //          ============ All plans for 3dbin ===============
                $packages_list = (isset($this->status['ListOfPackages']['Info'])) ? $this->status['ListOfPackages']['Info'] : [];
                if (isset($packages_list) && (!empty($packages_list)) && is_array($packages_list)) {
                    $packages_list = $this->packages_list($packages_list);
                } else {
                    $packages_list = array(
                        'options' => array(
                            'disable' => 'Disable (default)'
                        )
                    );
                }
            }
            if (isset($this->status['severity']) && ($this->status['severity'] == "SUCCESS")) {
                $this->set_curl_res_attributes();
                if ($this->lastUsageTime == '0000-00-00 00:00:00') {
                    $this->lastUsageTime = 'yyyy-mm-dd hrs-min-sec';
                }
                $subscription_time = (isset($this->subscriptionInfo) && (!empty($this->subscriptionInfo['subscriptionTime']))) ? "Start date: " . $this->formate_date_time($this->subscriptionInfo['subscriptionTime']) : "NA";
                $status_request_time = (isset($this->lastUsageTime) && (!empty($this->lastUsageTime))) ? '(' . $this->lastUsageTime . ')' : "NA";
                $expiry_time = (isset($this->subscriptionInfo) && (!empty($this->subscriptionInfo['expiryTime']))) ? "End date: " . $this->formate_date_time($this->subscriptionInfo['expiryTime']) : "NA";
                $subscribed_package = (isset($this->subscribedPackage) && (!empty($this->subscribedPackage))) ? $this->subscribed_package() : "NA";
                $consumed_hits = (isset($this->subscribedPackageHitsStatus) && (!empty($this->subscribedPackageHitsStatus['consumedHits']))) ? $this->subscribedPackageHitsStatus['consumedHits'] : "";
                $available_hits = (isset($this->subscribedPackageHitsStatus) && (!empty($this->subscribedPackageHitsStatus['availableHits']))) ? $this->subscribedPackageHitsStatus['availableHits'] . "/" : "NA";
                $consumedHits = (isset($this->subscribedPackageHitsStatus) && (!empty($this->subscribedPackageHitsStatus['consumedHits']))) ? $this->subscribedPackageHitsStatus['consumedHits'] . "/" : "0/";
                $consumed_hits_prcent = (isset($this->subscribedPackageHitsStatus) && (!empty($this->subscribedPackageHitsStatus['consumedHitsPrcent']))) ? $this->subscribedPackageHitsStatus['consumedHitsPrcent'] . "%" : "0%";
                $package_hits = (isset($this->subscribedPackageHitsStatus) && (!empty($this->subscribedPackageHitsStatus['packageHits']))) ? $this->subscribedPackageHitsStatus['packageHits'] : "/NA";
                $next_subcribed_package = (isset($this->nextSubcribedPackage) && (!empty($this->nextSubcribedPackage))) ? $this->next_subcribed_package() : "NA";
                if ($this->subscriptionStatus == "yes") {
                    $current_subscription = '<span id="subscribed_package">' . $subscribed_package . '</span>'
                        . '&nbsp;&nbsp;&nbsp; '
                        . '<span id="subscription_time">' . $subscription_time . '</span>'
                        . '&nbsp;&nbsp;&nbsp;'
                        . '<span id="expiry_time">' . $expiry_time . '</span>';
                    $current_usage = '<span id="subscribed_package_status">' . $consumedHits . $package_hits . '</span> '
                        . '&nbsp;&nbsp;&nbsp;'
                        . '<span id="consumed_hits_prcent">' . $consumed_hits_prcent . '</span>'
                        . '&nbsp;&nbsp;&nbsp;'
                        . '<span id="status_request_time">' . $status_request_time . '</span>';
                    $this->subscription_packages_response_for_pallet = "yes";
                    update_option("subscription_packages_response_for_pallet", $this->subscription_packages_response_for_pallet);

                } else {
                    $current_subscription = '<span id="subscribed_package">Your current subscription is expired.</span>';
                    $current_usage = 'Not available.';
                    $this->subscription_packages_response_for_pallet = "no";
                }
            } else {
                $current_subscription = '<span id="subscribed_package">Not subscribed.</span>';
                $current_usage = 'Not available.';
                //              ============== when no plan exist plan go to dislable =============
                $next_subcribed_package = "disable";
                $this->subscription_packages_response_for_pallet = "no";

                update_option("subscription_packages_response_for_pallet", $this->subscription_packages_response_for_pallet);
            }

            update_option("en_pallet_packaging_options_plans", $next_subcribed_package);

            $this->subscription_details = array('current_usage' => (isset($current_usage)) ? $current_usage : "",
                'current_subscription' => (isset($current_subscription)) ? $current_subscription : "",
                'next_subcribed_package' => (isset($next_subcribed_package)) ? $next_subcribed_package : "",
                'packages_list' => (isset($packages_list)) ? $packages_list : "",
                'subscription_packages_response_for_pallet' => (isset($this->subscription_packages_response_for_pallet)) ? $this->subscription_packages_response_for_pallet : "");
            return $this->subscription_details;
        }

        /**
         * new fields add for box sizing
         * @return array
         */
        function en_woo_addons_box_sizing_fields_arr($plugin_id)
        {
            $next_subcribed_package = $packages_list = $current_subscription = $current_usage = '';
            $this->plugin_name = $plugin_id;
            extract($this->subscription());
            $this->plugin_name = $plugin_id;
            $settings = array(
                'services_quoted_en_woo_pallet_addons_packages' => array(
                    'title' => __('', 'woocommerce'),
                    'name' => __('', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'desc' => '',
                    'id' => 'woocommerce_services_quoted_en_woo_pallet_addons_packages',
                    'css' => '',
                    'default' => '',
                    'type' => 'title',
                ),
                'en_pallet_sizing_options_label_description' => array(
                    'name' => __('', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'title',
                    'desc' => 'The Pallet Size feature calculates the optimal packaging solution based on your standard Pallet size. The solution is available graphically to assist order fulfillment. The next subscription begins when the current one expires or is depleted, which ever comes first. Refer to the <a target="_blank" href="https://eniture.com/woocommerce-pallet-packing/#documentation">User Guide</a> for more detailed information.',
                    'class' => 'hidden',
                    'id' => 'pallet_sizing_description'
                ),
                'en_pallet_packaging_options_plans' => array(
                    'name' => __('Auto-renew ', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'select',
                    'default' => $next_subcribed_package,
                    'id' => 'en_pallet_packaging_options_plans',
                    'class' => 'en_pallet_packaging_options_plans',
                    'options' => $packages_list['options']
                ),
                'en_pallet_sizing_current_subscription' => array(
                    'name' => __('Current plan', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'text',
                    'class' => 'hidden',
                    'desc' => $current_subscription,
                    'id' => "en_pallet_sizing_current_subscription"
                ),
                'en_pallet_sizing_current_usage' => array(
                    'name' => __('Current usage', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'text',
                    'class' => 'hidden',
                    'desc' => $current_usage,
                    'id' => 'en_pallet_sizing_current_usage'
                ),
                'suspend_automatic_detection_of_pallets' => array(
                    'name' => __('Suspend use', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'checkbox',
                    'id' => 'suspend_automatic_detection_of_pallets',
                    'desc' => __(' ', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'class' => 'suspend_automatic_detection_of_pallets'
                ),
                'en_pallet_sizing_plugin_name' => array(
                    'name' => __('', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'text',
                    'class' => "hidden",
                    'placeholder' => $this->plugin_name,
                    'id' => "en_pallet_sizing_plugin_name",
                ),
                'en_pallet_sizing_subscription_status' => array(
                    'name' => __('', 'woocommerce-settings-en_woo_pallet_addons_packages_quotes'),
                    'type' => 'text',
                    'class' => "hidden",
                    'placeholder' => $this->subscriptionStatus,
                    'id' => "en_pallet_sizing_subscription_status",
                ),
                'section_end_quote' => array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_quote_section_end'
                ),
                'section_end_quote_box_sizing' => array(
                    'type' => 'sectionend',
                    'id' => 'wc_settings_quote_section_end_pallet_sizing'
                )
            );
//                $settings = apply_filters('en_woo_addons_box_sizing_updated_fields_messages_apply_filters', $settings);
            return $settings;
        }

        /**
         * Formate the given date time @param $datetime like in sow
         * @param datetime $datetime
         * @return string
         */
        public function formate_date_time($datetime)
        {
            $date = date_create($datetime);
            return date_format($date, "M. d, Y");
        }

        /**
         * get_arr_filterd_val function see for if @param $arr_val type is array reset value return
         * @param array or string type $arr_val
         * @return string type
         */
        public function get_arr_filterd_val($arr_val)
        {

            return (isset($arr_val) && (!empty($arr_val))) ? (is_array($arr_val)) ? reset($arr_val) : $arr_val : "";
        }

        /**
         * Popup notification for using notification show during disable to plan through using jquery
         * @return html
         */
        public function en_woo_addons_popup_notifi_disabl_to_plan_pallet()
        {
            ?>
            <div id="plan_confirmation_popup" class="en_notification_disable_to_plan_overlay_pallet"
                 style="display: none;">
                <div class="en_pallet_notifi_disabl_to_plan_pallet">
                    <h2 class="del_hdng">
                        Note!
                    </h2>
                    <p class="confirmation_p">
                        Note! You have elected to enable the Standard Pallet feature. By confirming this election you
                        will be charged for the <span id="selected_plan_popup_pallet">[plan]</span> plan. To ensure
                        service continuity the plan will automatically renew each month, or when the plan is depleted,
                        whichever comes first. You can change which plan is put into effect on the next renewal date by
                        updating the selection on this page at anytime.
                    </p>
                    <div class="confirmation_btns">
                        <a style="cursor: pointer" class="cancel_plan">Cancel</a>
                        <a style="cursor: pointer" class="confirm_plan">OK</a>
                    </div>
                </div>
            </div>
            <?php
        }

        /**
         * Array merge after specific index
         * @param array $array
         * @param index of array $key
         * @param array $new
         * @return array
         */
        public function addon_array_insert_after(array $array, $key, array $new)
        {
            if (isset($key) && in_array($key, array_keys($array))) {
                $keys = array_keys($array);
                $index = array_search($key, $keys);
                $pos = false === $index ? count($array) : $index + 1;
                $array = array_merge(array_slice($array, 0, $pos), $new, array_slice($array, $pos));
            }
            return $array;
        }

        public function en_woo_pallet_addons_sections($sections, $plugin_id)
        {

            $this->sections = $sections;
            $this->plugins_dependencies = $this->plugins_dependencies();
            if (isset($this->plugins_dependencies[$plugin_id])) {
                $plugin_detail = $this->plugins_dependencies[$plugin_id];
                $addons = $plugin_detail['addons'];
                if ($addons['pallet_packaging_addon']['active'] === true) {
                    $key = key(array_slice($this->sections, -2, 1));
                    $new = array('section-pallet' => 'Pallet');
                    $this->sections = $this->addon_array_insert_after($this->sections, $key, $new);
                }
            }
            return $this->sections;
        }


        /**
         * Notifications html.
         */
        public function en_box_size_notifications_html()
        {
            ?>
            <!-- Notifications -->
            <div id="en_box_size_notifications_block">

                <!-- Delete message -->
                <div id="message" class="en_pallet_notification_delete updated inline" style="display:none">
                    <p>
                        <strong>Pallet deleted successfully.</strong>
                    </p>
                </div>

                <!-- Pallet Data saved -->
                <div id="message" class="en_pallet_notification_data_saved updated inline" style="display:none">
                    <p>
                        <strong>Pallet saved successfully.</strong>
                    </p>
                </div>

            </div>
            <?php
        }

        /**
         * box sizing table html
         * @return type
         */
        public function enPalletTable()
        {


            $this->en_box_size_notifications_html();

            $pallet_detail = json_decode(get_option('pallet'), TRUE);

            echo '<div class="add_box">';

            if (isset($pallet_detail) && (!empty($pallet_detail))) {
//                    echo '<a class="woocommerce-add-button" onClick="return edit_pallet_click()">Define Pallet</a>';
                echo '<a class="woocommerce-add-button" style="display: none;" onClick="return add_pallet_popup_click()">Add Pallet</a>';
            } else {
                echo '<a class="woocommerce-add-button" onClick="return add_pallet_popup_click()">Define pallet</a>';
            }

            echo '</div>';

            ?>

            <table class="en_pallet_list" id="">
                <thead>
                <tr>
                    <th>
                        Nickname
                    </th>
                    <th>
                        Length (in)
                    </th>
                    <th>
                        Width (in)
                    </th>
                    <th>
                        Max Height (in)
                    </th>

                    <th>
                        Pallet Height (in)
                    </th>

                    <th>
                        Max Weight (LBS)
                    </th>
                    <th>
                        Pallet Weight (LBS)
                    </th>
                    <th>
                        Available
                    </th>
                    <th>
                        Action
                    </th>
                </tr>
                </thead>
                <tbody>
                <tr>
                    <?php

                    $pallet_detail = json_decode(get_option('pallet'), TRUE);

                    if (isset($pallet_detail) && (!empty($pallet_detail))) {
                        $pallet_detail['en_pallet_available'] = (isset($pallet_detail['en_pallet_available'])) ? $pallet_detail['en_pallet_available'] : "No";

                        foreach ($pallet_detail as $key => $value) {

                            $value = $key == "en_pallet_available" ? '<a class="en_pallet_available" onclick="available()">' . $value . '</a>' : $value;

                            echo '<td class="' . $key . '_table">' . $value . '</td>';
                        }

                        $actions = '<td>';
                        $actions .= '<a class="en_pallet_action_pallet_sizing" onClick="return edit_pallet_click()"> Edit </a> | <a class="en_pallet_action_pallet_sizing" onclick="return delete_pallet_click()" id=""> Delete </a>';
                        $actions .= '</td>';

                        echo $actions;
                    }

                    ?>
                </tr>
                </tbody>
            </table>
            <?php

            $this->en_pallet_re_arrange_fields();
        }

        function en_woo_addons_box_sizing_text_fields_arr()
        {
            $box_sizes_popup = array(
                "en_pallet_nickname" => array(
                    "type" => "text",
                    "title" => "Nickname",
                    "label" => "Nickname",
                    "id" => "en_pallet_nickname",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "pallet_left",
                    "data_type" => "string",
                    "data_length" => ''),
                "en_pallet_sizing_length" => array(
                    "type" => "text",
                    "title" => "Length (in)",
                    "label" => "Length (in)",
                    "id" => "en_pallet_sizing_length",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "box_sizing_right",
                    "data_type" => "number",
                    "data_length" => 'data-length="108"'),
                "en_pallet_width" => array(
                    "type" => "text",
                    "title" => "Width (in)",
                    "label" => "Width (in)",
                    "id" => "en_pallet_width",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "pallet_left",
                    "data_type" => "number",
                    "data_length" => 'data-length="108"'),
                "en_pallet_sizing_height" => array(
                    "type" => "text",
                    "title" => "Max Height (in)",
                    "label" => "Max Height (in)",
                    "id" => "en_pallet_sizing_height",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "box_sizing_right",
                    "data_type" => "number",
                    "data_length" => 'data-length="108"'),

                "en_pallet_sizing_pallet_height" => array(
                    "type" => "text",
                    "title" => "Pallet Height (in)",
                    "label" => "Pallet Height (in)",
                    "id" => "en_pallet_sizing_pallet_height",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "pallet_left",
                    "data_type" => "number",
                    "data_length" => 'data-length="108"'),

                "en_pallet_sizing_max_weight" => array(
                    "type" => "text",
                    "title" => "Max Weight (LBS)",
                    "label" => "Max Weight (LBS)",
                    "id" => "en_pallet_sizing_max_weight",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "box_sizing_right",
                    "data_type" => "number",
                    "data_length" => 'data-length="150"'),
                "en_pallet_sizing_weight" => array(
                    "type" => "text",
                    "title" => "Pallet Weight (LBS)",
                    "label" => "Pallet Weight (LBS)",
                    "id" => "en_pallet_sizing_weight",
                    "class" => "add_pallet_popup_fields",
                    "placeholder" => "",
                    "position" => "pallet_left",
                    "data_type" => "number",
                    "data_length" => ''),
            );
            return array('fields' => $box_sizes_popup);
        }

        function en_pallet_re_arrange_fields()
        {
            ?>
            <!--</form>-->

            <div id="delete_dropship_btn" class="en_pallet_overlay add_pallet_popup">
                <!-- One Rate -->
            </div>

            <div id="delete_dropship_btn" class="en_add_pallet_overlay add_pallet_popup">
                <div class="en_add_pallet_popup">
                    <h2 class="del_hdng">
                        Pallet Properties
                    </h2>
                    <div class="girth_error">
                        <strong>Error!</strong> Length plus girth can not exceeds 165.
                    </div>
                    <form method="POST" id="en_pallet_sizing_input_fields">
                        <?php foreach ($this->box_sizing_text_fields_arr['fields'] as $key => $value) { ?>

                            <div class="en_pallet_sizing_input <?php echo $value['position']; ?>">
                                <label for="<?php echo $value['label']; ?>"><?php echo $value['label']; ?>
                                    <span>*</span> </label>
                                <input type="<?php echo $value['type']; ?>" name="<?php echo $value['id']; ?>"
                                       id="<?php echo $value['id']; ?>" <?php echo $value['data_length']; ?>
                                       title="<?php echo $value['title']; ?>"
                                       data-type="<?php echo $value['data_type']; ?>"
                                       class="<?php echo $value['class']; ?>"
                                       placeholder="<?php echo $value['placeholder']; ?>">
                                <span class="add_pallet_popup_err err"></span>
                            </div>

                        <?php } ?>
                        <div style="clear: both;"></div>
                        <div class="available_div">
                            <div for="available">Available</div>
                            <input type="checkbox" name="en_pallet_available" id="en_pallet_available" value="Yes"
                                   checked="checked"/>
                        </div>
                        <div class="del_btns en_pallet_sizing_input">
                            <a style="cursor: pointer" class="en_pallet_cancel">Cancel</a>
                            <a style="cursor: pointer" class="en_pallet_submit">Save</a>
                        </div>
                    </form>
                </div>
            </div>

            <?php
            /* Ouput the delete popup. */
            $this->en_return_delete_confirmation_popup();
        }

        /**
         * Ouput the delete popup.
         */
        public function en_return_delete_confirmation_popup()
        {
            ?>
            <div id="pallet_delete_popup" class="pallet_delete_popup">
                <a href="#delete_click_open_div" class="delete_pallet_btn hide_drop_val"></a>
                <div id="delete_click_open_div" class="pallent_css_overlay">
                    <div class="box_size_add_warehouse_popup">
                        <h2 class="del_hdng">
                            Warning!
                        </h2>
                        <p class="delete_p">
                            Are you sure you want to delete the pallet?
                        </p>
                        <div class="del_btns">
                            <a href="#" class="cancel_delete_pallet">Cancel</a>
                            <a href="#" class="confirm_delete_pallet">OK</a>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }

    new PackagingTab();
}


